@@ -4,6 +4,11 @@
 struct dcrypt_private_key;
 struct dcrypt_context_symmetric;
 
+enum decrypt_istream_format {
+	DECRYPT_FORMAT_V1,
+	DECRYPT_FORMAT_V2
+};
+
 /* Look for a private key for a specified public key digest and set it to
    priv_key_r. Returns 1 if ok, 0 if key doesn't exist, -1 on internal error. */
 typedef int
@@ -27,4 +32,8 @@ struct istream *
 i_stream_create_decrypt_callback(struct istream *input,
 				 i_stream_decrypt_get_key_callback_t *callback,
 				 void *context);
+
+enum decrypt_istream_format i_stream_encrypt_get_format(const struct istream *input);
+enum io_stream_encrypt_flags i_stream_encrypt_get_flags(const struct istream *input);
+
 #endif
